# Table of Contents

- [portals](<./portals.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Portals](<./Portals.md>)
  - [Overview](<./Portals/Overview.md>)
  - [Use the Portal Feature](<./Portals/Use-the-Portal-Feature.md>)
  - [Portal Permissions](<./Portals/Portal-Permissions.md>)
  - [Configure a Portal](<./Portals/Configure-a-Portal.md>)
  - [Basic](<./Portals/Basic.md>)
  - [Status](<./Portals/Status.md>)
  - [Search](<./Portals/Search.md>)
  - [Detailed View](<./Portals/Detailed-View.md>)
  - [Branding](<./Portals/Branding.md>)
  - [Localization](<./Portals/Localization.md>)
  - [Advanced](<./Portals/Advanced.md>)
  - [Was this page helpful?](<./Portals/Was-this-page-helpful.md>)
